@@ -13,18 +13,32 @@ def periodic(refresh_interval: Tuple) -> Callable:
         async def wrapper(*args: Any, **kwargs: Any) -> None:
             sleep_time = random.randint(*refresh_interval)
             method_info = f"[{func.__module__}::{func.__qualname__}]"
-            _LOGGER.info(
+            _LOGGER.debug(
                 "Sleep time for periodic task: %s is %s seconds",
                 method_info,
                 sleep_time,
             )
             while True:
                 try:
-                    _LOGGER.info("executing periodic task %s", method_info)
+                    _LOGGER.debug(
+                        "[%s] executing periodic task %s",
+                        asyncio.current_task(),
+                        method_info,
+                    )
                     await func(*args, **kwargs)
+                except asyncio.CancelledError:
+                    _LOGGER.debug(
+                        "[%s] Periodic task %s cancelled",
+                        asyncio.current_task(),
+                        method_info,
+                    )
+                    break
                 except Exception:
                     _LOGGER.warning(
-                        "Failed to poll using function %s", method_info, exc_info=True
+                        "[%s] Failed to poll using function %s",
+                        asyncio.current_task(),
+                        method_info,
+                        exc_info=True,
                     )
                 await asyncio.sleep(sleep_time)
 
