@@ -2,10 +2,11 @@
 from __future__ import annotations
 
 import asyncio
+from contextlib import suppress
 from enum import Enum
 import logging
 import time
-from typing import TYPE_CHECKING, Any, Callable, Final, Iterable, Union
+from typing import TYPE_CHECKING, Any, Final, Iterable, Union
 
 from zigpy import types
 from zigpy.device import Device as ZigpyDevice
@@ -126,11 +127,9 @@ class Device(LogMixin):
         """Initialize the gateway."""
         self._controller: Controller = controller
         self._zigpy_device: ZigpyDevice = zigpy_device
-        #       self._zha_gateway = zha_gateway
         self._available: bool = False
-        #       self._available_signal = f"{self.name}_{self.ieee}_{SIGNAL_AVAILABLE}"
         self._checkins_missed_count: int = 0
-        self.unsubs: list[Callable[[], Any]] = []
+        self._tracked_tasks: list[asyncio.Task] = []
         self.quirk_applied: bool = isinstance(
             self._zigpy_device, zigpy.quirks.CustomDevice
         )
@@ -170,7 +169,12 @@ class Device(LogMixin):
             if ep_id != 0:
                 self._endpoints[ep_id] = Endpoint.new(endpoint, self)
 
-        self._check_alive_task = asyncio.create_task(self._check_available())
+        if not self.is_coordinator:
+            self._tracked_tasks.append(
+                asyncio.create_task(
+                    self._check_available(), name=f"device_check_alive_{self.ieee}"
+                )
+            )
 
     @property
     def device(self) -> ZigpyDevice:
@@ -324,7 +328,11 @@ class Device(LogMixin):
     def zigbee_signature(self) -> dict[str, Any]:
         # Get zigbee signature for this device.
         return {
-            ATTR_NODE_DESCRIPTOR: self._zigpy_device.node_desc.as_dict(),
+            ATTR_NODE_DESCRIPTOR: (
+                self._zigpy_device.node_desc.as_dict()
+                if self._zigpy_device.node_desc is not None
+                else None
+            ),
             ATTR_ENDPOINTS: {
                 signature[0]: signature[1]
                 for signature in [
@@ -508,10 +516,16 @@ class Device(LogMixin):
         self.status = DeviceStatus.INITIALIZED
         self.debug("completed initialization")
 
-    def async_cleanup_handles(self) -> None:
-        """Unsubscribe the dispatchers and timers."""
-        for unsubscribe in self.unsubs:
-            unsubscribe()
+    async def on_remove(self) -> None:
+        """Cancel tasks this device owns."""
+        for task in self._tracked_tasks:
+            if not task.done():
+                self.debug("Cancelling task: %s", task)
+                task.cancel()
+                with suppress(asyncio.CancelledError):
+                    await task
+            for platform_entity in self._platform_entities.values():
+                await platform_entity.on_remove()
 
     def async_update_last_seen(self, last_seen: float) -> None:
         """Set last seen on the zigpy device."""
